#
# spec file
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019-2024 Dr. Axel Braun <DocB@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define base_name python-barcode
Name:           python-%{base_name}
Version:        0.15.1
Release:        2.6
Summary:        Library to create Barcodes with Python
License:        MIT
URL:            https://github.com/WhyNotHugo/python-barcode
Source:         https://files.pythonhosted.org/packages/source/p/%{base_name}/%{base_name}-%{version}.tar.gz
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dejavu-fonts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       dejavu-fonts
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-pyBarcode = %{version}-%{release}
Obsoletes:      python-pyBarcode < %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
Library to create standard barcodes with Python. No external modules needed (optional PIL support included).

%prep
%setup -q -n %{base_name}-%{version}
# Fix rpmlint warning about too many +x perms when these files get installed later.
find . -type f -exec chmod a-x {} +
# doc buildscripts we don't wanna ship
rm docs/Makefile

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/python-barcode
%python_expand %fdupes %{buildroot}%{$python_sitelib}
find %{buildroot} -type f -name "*.ttf" | while read i; do
	ln -fs "%{_datadir}/fonts/truetype/${i##*/}" "$i"
done
%{python_expand # copy docs for deduplication
mkdir -p %{buildroot}%{_docdir}
cp -r docs %{buildroot}%{_docdir}/$python-python-barcode
%fdupes %{buildroot}%{_docdir}/$python-python-barcode
}

%check
sed -i '/cov/d' setup.cfg
%pytest

%post
%python_install_alternative python-barcode

%postun
%python_uninstall_alternative python-barcode

%files %{python_files}
%license LICENCE
%doc %{_docdir}/%{python_flavor}-python-barcode
%{python_sitelib}/barcode
%{python_sitelib}/python_barcode-%{version}*-info
%python_alternative %{_bindir}/python-barcode

%changelog
* Sun Jan 14 2024 Axel Braun <axel.braun@gmx.de>
- enabled %%{?sle15_python_module_pythons}
* Wed Sep 20 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.15.1
  * Improved type hints.
  * Updated ISBN to support newer allocated ranges.
  * Fixed compatibility with Pillow 10.0.
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.14.0
  * Breaking: The default dimensions have changed slightly. This is
    so that the results of generating a PNG and an SVG look more
    alike.
  * Previous versions included an empty text element for SVGs with
    no comment. This is no longer the case.
  * Some internals have been improved so as to allow better
    subclassing. Subclasses of Barcode can now override
    default_writer_options and default_writer().
  * A guardbar parameter has been added to EAN barcodes. This
    renders barcodes with guardars (longer bars).
  * Added support for Python 3.10.
  * The documentation setup has been redone, hopefully squashing a
    lot of legacy quirks.
  * Previous versions installed the tests module. This was not
    intentional and have been fixed.
- Remove ancient pathlib dependency
* Mon Oct 26 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.13.1:
  * Fix a crash when using the generate shortcut function.
  * Added support for transparent backgrounds. This is done by setting the
    mode option for a writer to RGBA.
  * Removed writer_options from barcode.get. This parameter was not used.
  * Add a with_doctype flag to SVGWriter. Set this to false to avoid including
    a DOCTYPE in the resulting SVG.
  * Add support for Pillow>=8.0.0.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Mar 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove tests folder that was installed in sitelib
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 0.11.0
  * Added basic support for multiline text.
  * Dropped lots of older compat-only code and other cleanups.
  * Fixed a bug in the API when combining certain barcodes and writers.
  * Published documentation again and updated all project references.
  * Fix python_barcode.get mixups between options as writer_options. Previously, some writer/barcode combinations worked fine, while others failed. Now all work consistently.
  * The cli tool has been fixed and should now work as expected again.
* Sat May 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.10.0:
  * Various minor fixes and tweaks
  * CI integration fixes
* Sat Apr  6 2019 Jan Engelhardt <jengelh@inai.de>
- Unbundle DejaVu font and reuse the one from the system.
* Thu Apr  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Provide and obsolete pyBarcode as we are fork of it
* Wed Apr  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Run the spec-cleaner
* Mon Mar 25 2019 Axel Braun <axel.braun@gmx.de>
- Verion 0.9 of python-barcode (fork of pyBarcode)
  initial OBS build
